#!/bin/bash
set -eu -o pipefail

rspec_file=rspec.json
service_count=`jq '. | length' ${rspec_file}`
i=0
while [  $i -lt ${service_count} ]; do
    service_name_key=".[${i}].name"
    service_name=`jq ${service_name_key} ${rspec_file} | tr -d '"'`

    if ! lxc-info -n ${service_name}; then
        echo "Creating container: ${service_name}"
        lxc-create -t download -n ${service_name} -- --dist ubuntu --release xenial --arch amd64
        
        ip_key=".[${i}].ip_address"
        ip=`jq ${ip_key} ${rspec_file} | tr -d '"'`
        echo "dhcp-host=${service_name},${ip}" >> /etc/lxc/dnsmasq.conf

        echo "Coping files"
        container_dir="/var/lib/lxc/"${service_name}"/rootfs"
        container_vagrant_dir=${container_dir}"/vagrant"

        mkdir -p ${container_vagrant_dir}
        cp -f /vagrant/reporc "${container_vagrant_dir}"
        cp -rf /vagrant/scripts ${container_vagrant_dir}
        cp -rf /vagrant/clmctest ${container_vagrant_dir}

        # start the container
        lxc-start -n ${service_name}
        sleep 4

        echo "Provisioning: ${service_name}"
        if [ ${service_name} == "clmc-service" ]
        then
            cmd=/vagrant/scripts/clmc-service/install.sh
            lxc-attach -n ${service_name} -- ${cmd}
        elif [ ${service_name} == "test-runner" ]
        then
            cmd=/vagrant/clmctest/services/pytest/install.sh
            lxc-attach -n ${service_name} -- ${cmd}
        else
            sf_id_key=".[${i}].sf_id"
            sf_id=`jq ${sf_id_key} ${rspec_file} | tr -d '"'`        
            cmd=/vagrant/clmctest/services/${sf_id}/install.sh
            lxc-attach -n ${service_name} -v REPO_ROOT=/vagrant -- ${cmd}

            cmd=/vagrant/scripts/clmc-agent/install.sh
            lxc-attach -n ${service_name} -v REPO_ROOT=/vagrant -- ${cmd}

            cp -f /vagrant/scripts/clmc-agent/telegraf.conf ${container_dir}/etc/telegraf/ 
            cp -f /vagrant/scripts/clmc-agent/telegraf_output.conf ${container_dir}/etc/telegraf/telegraf.d/                
            cp /vagrant/clmctest/services/${sf_id}/telegraf_${sf_id}.conf ${container_dir}/etc/telegraf/telegraf.d/ 

            cmd=/vagrant/scripts/clmc-agent/configure_template.sh
            lxc-attach -n ${service_name} -- ${cmd}

            location_key=".[${i}].location"
            location=`jq ${location_key} ${rspec_file} | tr -d '"'`
            sfc_id_key=".[${i}].sfc_id"
            sfc_id=`jq ${sfc_id_key} ${rspec_file} | tr -d '"'`
            sfc_id_instance_key=".[${i}].sfc_id_instance"
            sfc_id_instance=`jq ${sfc_id_instance_key} ${rspec_file} | tr -d '"'`
            sf_id_key=".[${i}].sf_id"
            sf_id=`jq ${sf_id_key} ${rspec_file} | tr -d '"'`
            sf_id_instance_key=".[${i}].sf_id_instance"
            sf_id_instance=`jq ${sf_id_instance_key} ${rspec_file} | tr -d '"'`
            ipendpoint_id_key=".[${i}].ipendpoint_id"
            ipendpoint_id=`jq ${ipendpoint_id_key} ${rspec_file} | tr -d '"'`
            sr_id_key=".[${i}].sr_id"
            sr_id=`jq ${sr_id_key} ${rspec_file} | tr -d '"'`
            influxdb_url_key=".[${i}].influxdb_url"
            influxdb_url=`jq ${influxdb_url_key} ${rspec_file} | tr -d '"'` 
            database_name_key=".[${i}].database_name"
            database_name=`jq ${database_name_key} ${rspec_file} | tr -d '"'`  

            cmd="/vagrant/scripts/clmc-agent/configure.sh ${location} ${sfc_id} ${sfc_id_instance} ${sf_id} ${sf_id_instance} ${ipendpoint_id} ${sr_id} ${influxdb_url} ${database_name}"

            lxc-attach -n ${service_name} -- ${cmd}

            lxc-attach -n ${service_name} -- service telegraf restart    
        fi 
    fi
    let i=i+1
done

./conts-stop.sh

service lxc-net restart

./conts-start.sh